genomeshader
""""""""""""

|GitHub release| |PyPI version genomeshader|

.. |GitHub release| image:: https://img.shields.io/github/release/broadinstitute/genomeshader.svg
   :target: https://github.com/broadinstitute/genomeshader/releases/

.. |PyPI version genomeshader| image:: https://img.shields.io/pypi/v/genomeshader.svg
   :target: https://pypi.python.org/pypi/genomeshader/

Genomeshader is a Python library for viewing read level data spanning variants across thousands of samples.

Documentation for the Genomeshader API can be found on the `documentation page <https://broadinstitute.github.io/genomeshader/>`_.

Installation
------------

``pip`` is recommended for Genomeshader installation.

::

   pip install genomeshader 

::

   git clone https://github.com/broadinstitute/genomeshader.git
   maturin develop --release

Getting help
------------

If you encounter bugs or have questions/comments/concerns, please file an issue on our `Github page <https://github.com/broadinstitute/genomeshader/issues>`_.

Developers' guide
-----------------

For information on contributing to Genomeshader development, visit our `developer documentation <DEVELOP.md>`_.
